/*******************************************************************************
***
*** Filename         : rfsv.h
*** Purpose          : SYS$RFSV.* "process" Application Layer.
*** Author           : Matt J. Gumbley
*** Created          : 21/01/99
*** Last updated     : 21/01/99
***
********************************************************************************
***
*** Modification Record
***
*******************************************************************************/

#ifndef RFSV_H
#define RFSV_H

/* We keep track of opened files in these structures - we don't pass real file
 * descriptors back via the RFSV protocol, instead, we pass indices into the
 * open_files array.
 */
struct open_file {
  int active;
  int fd; /* Used for type F_STREAM (file opens) */
  DIR *dir; /* Used for type F_DIR (directory opens) */
  word16 type;
};

#define MAX_OPEN_FILES  16

/* State needed for RFSV channels */
struct rfsv_state {
  int in_write;    /* Whether in the middle of a write (i.e. no protocol frame
                      headers, just data */
  int in_read;     /* Whether in the middle of a read (i.e. no protocol frame
                      headers, just data */
  word16 last_cmd; /* The last command seen on this channel - this is used 
                      to determine what type of response is being sent */
  struct open_file open_files[MAX_OPEN_FILES];
};

/* Structure of a response frame */
struct rfsv_response {
  word16 type;
  word16 len;
  word16 result;
  byte   data[PLP_FRAMESIZE-6];
};

/* Structure of a message from remote RFSV */
struct rfsv_msg {
  word16 type;
  word16 len;
  byte   data[PLP_FRAMESIZE-4];
};



extern struct rfsv_state *rfsv_alloc(void);
extern void rfsv_free(struct rfsv_state *);
extern int rfsv_handle(struct ncp_channel *, byte *, int);

#endif /* RFSV_H */

